==> openGion6.7.2.0_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2017/01/05 15:19:19                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            varchar (  20 )                 NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            varchar ( 100 )                                     /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           varchar (  30 )                                     /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         varchar ( 500 )                                     /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                     /*  70 設変番号     */
 , PRT_GRP          varchar (  20 )                                     /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          varchar (  50 )                                     /* 150 ﾎｽﾄ          */
 , FGJ              varchar (   1 )     DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                     /* 820 登録日時     */
 , PGSET            varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                     /* 850 作成社員     */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                     /* 890 更新者       */
);

==> openGion6.8.3.0_core.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            varchar (  20 )                 NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            varchar ( 100 )                                     /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           varchar (  30 )                                     /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         varchar ( 500 )                                     /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar (  20 )                                     /*  70 設変番号     */
 , PRT_GRP          varchar (  20 )                                     /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          varchar (  50 )                                     /* 150 ﾎｽﾄ          */
 , FGJ              varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar (  14 )                                     /* 820 登録日時     */
 , PGSET            varchar (  10 )                                     /* 830 作成PG       */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG     */
 , USRSET           varchar (  10 )                                     /* 850 作成社員     */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時     */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG       */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG     */
 , USRUPD           varchar (  10 )                                     /* 890 更新者       */
);
